+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0629      ; [.1C54.0020.0002.062A] # ARABIC LETTER TEH MARBUTA
FE93      ; [.1C54.0020.0002.062A] # ARABIC LETTER TEH MARBUTA ISOLATED FORM
FE94      ; [.1C54.0020.0002.062A] # ARABIC LETTER TEH MARBUTA FINAL FORM
ENTRY
};
